#
# Copyright 2012-2013 Corporation of Balclutha (http://www.balclutha.org)
# 
#                All Rights Reserved
# 
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
#
# Corporation of Balclutha DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS
# SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
# AND FITNESS, IN NO EVENT SHALL Corporation of Balclutha BE LIABLE FOR
# ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
# WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
# ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
# PERFORMANCE OF THIS SOFTWARE. 
#

import logging, transaction
from Products.ZenModel.ZenPack import ZenPack as ZenPackBase
from Products.CMFCore.DirectoryView import registerDirectory

from lbn.zenoss import packutils

from config import *
import setuphandlers

logger = logging.getLogger(PROJECTNAME)
logger.info('Installing ZenPacks.lbn.Base module')

registerDirectory(SKINS_DIR, GLOBALS)


from lbn.zenoss import packutils
import setuphandlers


class ZenPack(ZenPackBase):
    """ ZenPack for pre-loaded python modules installed in sitelib/sitearch """

    # remove loaders that attempt to do file-system stuff (ZPLDaemons,...)
    loaders = ZenPackBase.loaders[0:2] + ZenPackBase.loaders[3:]

    def install(self, pack):
        """
        Set the collector plugin
        """
        ZenPackBase.install(self, pack)

    def removeZProperties(self, app):
        """
        Remove any zProperties defined in the ZenPack

        @param app: ZenPack
        @type app: ZenPack object
        """
        for name, value, pType in self.packZProperties:
            try:
                app.zport.dmd.Devices._delProperty(name)
            except AttributeError:
                pass

    def shouldDeleteFilesOnRemoval(self):
        """ hell no - these are all RPM-controlled, most probably with root permissions """
        return False

    # continue if loader errors ...
    def _X_remove(self, app, leaveObjects=False):
        """
        This prepares the ZenPack for removal but does not actually remove
        the instance from ZenPackManager.packs  This is sometimes called during
        the course of an upgrade where the loaders' unload methods need to
        be run.

        @param app: ZenPack
        @type app: ZenPack object
        @param leaveObjects: remove zProperties and things?
        @type leaveObjects: boolean
        """
        if not leaveObjects:
            self.stopDaemons()
        for loader in self.loaders:
            try:
                loader.unload(self, app, leaveObjects)
            except Exception, e:
                logger.error(str(e), exc_info=True)
        if not leaveObjects:
            self.removeZProperties(app)
            self.removeCatalogedObjects(app)

def initialize(context):
    """ Zope Product """
    zport = packutils.zentinel(context)
    if zport:
	if not packutils.hasZenPack(zport, __name__):
            logger.info('Installing into ZenPackManager')
	    zpack = ZenPack(__name__)
            transaction.begin()
            zpack = packutils.addZenPack(zport, zpack)
            setuphandlers.install(zport, zpack)
            transaction.commit()
        else:
            logger.info('Already in ZenPackManager')
    else:
	logger.error('No Zentinel: do http://localhost:<port>/@@zentinel')

        



#
#    Copyright 2010-2013 Corporation of Balclutha (http://www.balclutha.org)
# 
#                All Rights Reserved
# 
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE
#
import logging
from Acquisition import aq_base
from lbn.zenoss.packutils import addZenPackObjects
from config import PROJECTNAME

logger = logging.getLogger(PROJECTNAME)
info = logger.info

ZENPACKS = (
    ('ZenPacks.lbn.Base', """Last Bastion Network shims for Zenoss"""),
    ('ZenPacks.lbn.ZopeMonitor', """Performance statistics of (remote) Zope server"""),
    ('ZenPacks.lbn.LDAPMonitor', """Performance statistics of (remote) LDAP server"""),
    ('ZenPacks.oie.Kannel', """Performance statistics of (remote) Kannel SMPP/SMSC server"""),
    )

def addBranding(dmd, zenpack):
    """
    Add LBN Manufacturer/Software into Zenoss
    """
    manufacturers = dmd.Manufacturers

    if not getattr(aq_base(manufacturers), 'LBN', None):
        info('adding Manufacturer - LBN')
        manufacturers.manage_addProduct['ZenModel'].manage_addManufacturer('LBN')
        manufacturers.LBN.manage_changeProperties(url='http://au.last-bastion.net',
                                                  supportNumber='+61 2 8399 1271',
                                                  address1='407 The Foundry, 181 Lawson Street',
                                                  address2='Darlington',
                                                  city='Sydney',
                                                  state='NSW',
                                                  country='Australia',
                                                  zip='2008')

    lbn = manufacturers.LBN
    products = lbn.products

    for packname, desc in ZENPACKS:
        if not getattr(aq_base(products), packname, None):
            info('adding product - %s' % packname)
            lbn.manage_addSoftware(prodName=packname)
            getattr(products, packname).manage_changeProperties(description=desc)

    if not getattr(aq_base(products), 'BastionLinux', None):
        info('adding software - BastionLinux')
        lbn.manage_addSoftware(prodName='BastionLinux', isOS=True)
        bl = products.BastionLinux
        bl.manage_changeProperties(description="Enterprise Zope/Plone/Zenoss Distro http://linux.last-bastion.net")

    addZenPackObjects(zenpack, (lbn,))



#
#    Copyright 2010 Corporation of Balclutha (http://www.balclutha.org)
# 
#                All Rights Reserved
# 
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE
#
from os import path

PROJECTNAME = "ZenPacks.lbn.Base"
# ZenUtils expects full skin path in it's registration lookup
SKINS_DIR = path.join(path.dirname(__file__), 'skins')
SKINNAME = PROJECTNAME
GLOBALS = globals()



#
# Copyright 2012 Corporation of Balclutha (http://www.balclutha.org)
# 
#                All Rights Reserved
# 
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
#
#
# Corporation of Balclutha DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS
# SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
# AND FITNESS, IN NO EVENT SHALL Corporation of Balclutha BE LIABLE FOR
# ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
# WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
# ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
# PERFORMANCE OF THIS SOFTWARE. 
#
from brand import addBranding

def install(zport, zenpack):
    """
    Set the collector plugin
    """
    dmd = zport.dmd
    addBranding(dmd, zenpack)

def uninstall(zport):
    pass
                       



#
# Copyright 2012-2013 Corporation of Balclutha (http://www.balclutha.org)
# 
#                All Rights Reserved
# 
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE
#


from setuptools import setup, find_packages

################################
# These variables are overwritten by Zenoss when the ZenPack is exported
# or saved.  Do not modify them directly here.
# NB: PACKAGES is deprecated
NAME = "ZenPacks.lbn.Base"
VERSION = "4.0.3"
AUTHOR = "Last Bastion Network"
LICENSE = "ZPL/2.1"
NAMESPACE_PACKAGES = ['ZenPacks', 'ZenPacks.lbn']
PACKAGES = ['ZenPacks', 'ZenPacks.lbn', 'ZenPacks.lbn.Base']
INSTALL_REQUIRES = ['lbn.zenoss>=4.2.0']
COMPAT_ZENOSS_VERS = ">=3.0"
PREV_ZENPACK_NAME = ""
# STOP_REPLACEMENTS
################################
# Zenoss will not overwrite any changes you make below here.

def read(name):
    return open(name).read()


long_description=(
        read('README.txt')
        + '\n' +
        read('CHANGES.txt')
    )


setup(name='ZenPacks.lbn.Base',
      version=VERSION,
      description="Base wrappers to save real Zopistas from Zenoss cruft",
      long_description=long_description,
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Framework :: Zope2",
        "Framework :: Plone",
        "Intended Audience :: Information Technology",
        "Programming Language :: Python",
        "Programming Language :: Zope",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved :: Zope Public License",
        "Topic :: System :: Monitoring",
        "Topic :: System :: Networking :: Monitoring",
        ],
      keywords='lbn zenoss',
      author='Last Bastion Network',
      author_email='alan.milligan@last-bastion.net',
      url='http://linux.last-bastion.net/LBN/up2date/monitor',
      license='ZPL/2.1',
      packages=find_packages(),
      namespace_packages=NAMESPACE_PACKAGES,
      include_package_data=True,
      zip_safe=False,
      install_requires=INSTALL_REQUIRES,
      entry_points="""
      # -*- Entry points: -*-
      [zope2.initialize]
      ZenPacks.lbn.Base = ZenPacks.lbn.Base:initialize
      [zenoss.zenpacks]
      ZenPacks.lbn.Base = ZenPacks.lbn.Base
      """
)



#
# Copyright 2011 Corporation of Balclutha (http://www.balclutha.org)
# 
#                All Rights Reserved
# 
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
#
# Corporation of Balclutha DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS
# SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
# AND FITNESS, IN NO EVENT SHALL Corporation of Balclutha BE LIABLE FOR
# ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
# WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
# ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
# PERFORMANCE OF THIS SOFTWARE. 
#

# See http://peak.telecommunity.com/DevCenter/setuptools#namespace-packages
try:
    __import__('pkg_resources').declare_namespace(__name__)
except ImportError:
    from pkgutil import extend_path
    __path__ = extend_path(__path__, __name__)
